groff-commit
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[groff] 06/21: [docs]: Standardize spelling of "whitespace".


From: G. Branden Robinson
Subject: [groff] 06/21: [docs]: Standardize spelling of "whitespace".
Date: Fri, 28 Jul 2023 07:51:14 -0400 (EDT)

gbranden pushed a commit to branch master
in repository groff.

commit a91ce29522ab9d49507f35d5e79500609c6d8e9b
Author: G. Branden Robinson <g.branden.robinson@gmail.com>
AuthorDate: Thu Jul 27 00:50:38 2023 -0500

    [docs]: Standardize spelling of "whitespace".
    
    The single-word form is by far more preponderant, and I prefer it
    because such space is often not literally "white".
    
    $ printf 'Check out my \\M[red]red space\\M[].\n.pl \\n[nl]u\n' | nroff
    
    Also update a bunch of code comments similarly.
    
    Not changed: contrib/mom and contrib/pdfmark
---
 doc/meintro.me.in                  | 4 ++--
 man/groff.7.man                    | 2 +-
 src/devices/grohtml/html-table.cpp | 8 ++++----
 src/devices/grohtml/html-text.cpp  | 2 +-
 src/devices/grotty/tty.cpp         | 2 +-
 src/include/font.h                 | 6 +++---
 src/libs/libdriver/input.cpp       | 6 +++---
 src/libs/libgroff/quotearg.c       | 4 ++--
 src/preproc/grn/grn.1.man          | 2 +-
 src/preproc/grn/main.cpp           | 2 +-
 src/preproc/html/pushback.cpp      | 2 +-
 src/preproc/refer/ref.cpp          | 2 +-
 src/roff/troff/input.cpp           | 4 ++--
 tmac/groff_mdoc.7.man              | 2 +-
 14 files changed, 24 insertions(+), 24 deletions(-)

diff --git a/doc/meintro.me.in b/doc/meintro.me.in
index ac23ce605..1b70506d0 100644
--- a/doc/meintro.me.in
+++ b/doc/meintro.me.in
@@ -423,7 +423,7 @@ sometimes called the
 of the output page.
 Most of these requests adjust the placing
 of
-.q "white space"
+.q whitespace
 (blank lines or spaces).
 In these explanations,
 characters in italics
@@ -480,7 +480,7 @@ The
 .b .in \ \c
 .i +N
 request
-changes the amount of white space
+changes the amount of whitespace
 on the left of the page
 (the
 .i indent ).
diff --git a/man/groff.7.man b/man/groff.7.man
index ce1ae7779..fd9d4d2dd 100644
--- a/man/groff.7.man
+++ b/man/groff.7.man
@@ -494,7 +494,7 @@ the Control+A character (U+0001) in text is interpreted as a
 .
 .
 .P
-Horizontal white space characters are significant to
+Horizontal whitespace characters are significant to
 .I groff,
 but trailing spaces on text lines are ignored.
 .\" slack text for widow/orphan control: trailing tabs are not
diff --git a/src/devices/grohtml/html-table.cpp 
b/src/devices/grohtml/html-table.cpp
index 3d7dfcd52..0295da4df 100644
--- a/src/devices/grohtml/html-table.cpp
+++ b/src/devices/grohtml/html-table.cpp
@@ -96,14 +96,14 @@ int tabs::compatible (const char *s)
     s++;
 
   while (*s != (char)0 && last != NULL) {
-    // move over white space
+    // move over whitespace
     while ((*s != (char)0) && isspace(*s))
       s++;
     // collect alignment
     align = *s;
     // move over alignment
     s++;
-    // move over white space
+    // move over whitespace
     while ((*s != (char)0) && isspace(*s))
       s++;
     // collect tab position
@@ -136,14 +136,14 @@ void tabs::init (const char *s)
     s++;
 
   while (*s != (char)0) {
-    // move over white space
+    // move over whitespace
     while ((*s != (char)0) && isspace(*s))
       s++;
     // collect alignment
     align = *s;
     // move over alignment
     s++;
-    // move over white space
+    // move over whitespace
     while ((*s != (char)0) && isspace(*s))
       s++;
     // collect tab position
diff --git a/src/devices/grohtml/html-text.cpp 
b/src/devices/grohtml/html-text.cpp
index b07cbe7a0..ff7263a10 100644
--- a/src/devices/grohtml/html-text.cpp
+++ b/src/devices/grohtml/html-text.cpp
@@ -805,7 +805,7 @@ void html_text::do_newline (void)
 }
 
 /*
- *  emitted_text - returns FALSE if white space has just been written.
+ *  emitted_text - returns FALSE if whitespace has just been written.
  */
 
 int html_text::emitted_text (void)
diff --git a/src/devices/grotty/tty.cpp b/src/devices/grotty/tty.cpp
index 45926f668..1b92ad8c0 100644
--- a/src/devices/grotty/tty.cpp
+++ b/src/devices/grotty/tty.cpp
@@ -474,7 +474,7 @@ void tty_printer::special_link(const char *arg, const 
environment *env)
     is_link_active = false;
   }
   else {
-    // Our caller ensures that we see white space after 'link'.
+    // Our caller ensures that we see whitespace after 'link'.
     assert(c == ' ' || c == '\t');
     if (is_link_active) {
       warning("new hyperlink started without ending previous one;"
diff --git a/src/include/font.h b/src/include/font.h
index 68a82faf2..4e447f4d5 100644
--- a/src/include/font.h
+++ b/src/include/font.h
@@ -163,16 +163,16 @@ public:
                        // (one of LIG_ff, LIG_fi, ...).
   int get_italic_correction(glyph *, int);     // If the given glyph (arg1)
                        // at the given point size (arg2) is followed by an
-                       // unslanted glyph, some horizontal white space may
+                       // unslanted glyph, some horizontal whitespace may
                        // need to be inserted in between.  See the groff
                        // manual, description of \/.  Return the amount
-                       // (width) of this white space.
+                       // (width) of this whitespace.
   int get_left_italic_correction(glyph *, int);        // If the given glyph 
(arg1)
                        // at the given point size (arg2) is preceded by an
                        // unslanted roman glyph, some horizontal white
                        // space may need to be inserted in between.  See
                        // the groff manual, description of \,.  Return the
-                       // amount (width) of this white space.
+                       // amount (width) of this whitespace.
   int get_subscript_correction(glyph *, int);  // If the given glyph (arg1)
                        // at the given point size (arg2)is followed by a
                        // subscript glyph, the horizontal position may need
diff --git a/src/libs/libgroff/quotearg.c b/src/libs/libgroff/quotearg.c
index 75eaca8f0..6d2126bd3 100644
--- a/src/libs/libgroff/quotearg.c
+++ b/src/libs/libgroff/quotearg.c
@@ -69,7 +69,7 @@ needs_quoting(const char *string)
         
   while (*string) {
     /* Scan non-NULL strings, up to '\0' terminator,
-     * returning 'TRUE' if quote or white space found.
+     * returning 'TRUE' if quote or whitespace found.
      */
 
     if (*string == '"' || isspace(*string))
@@ -80,7 +80,7 @@ needs_quoting(const char *string)
     ++string;
   }
 
-  /* Fall through, if no quotes or white space found,
+  /* Fall through, if no quotes or whitespace found,
    * in which case, return 'FALSE'.
    */
 
diff --git a/src/preproc/grn/grn.1.man b/src/preproc/grn/grn.1.man
index cbc15ae86..df979c2be 100644
--- a/src/preproc/grn/grn.1.man
+++ b/src/preproc/grn/grn.1.man
@@ -174,7 +174,7 @@ may have one
 .I @g@grn
 command.
 .
-Commands consist of one or two strings separated by white space,
+Commands consist of one or two strings separated by whitespace,
 the first string being the command and the second its operand.
 .
 Commands may be upper- or lowercase and abbreviated down to one
diff --git a/src/preproc/grn/main.cpp b/src/preproc/grn/main.cpp
index 6d6d58669..8dab295c0 100644
--- a/src/preproc/grn/main.cpp
+++ b/src/preproc/grn/main.cpp
@@ -14,7 +14,7 @@
  *
  * Inside the GS and GE, commands are accepted to reconfigure the
  * picture.  At most one command may reside on each line, and each
- * command is followed by a parameter separated by white space.  The
+ * command is followed by a parameter separated by whitespace.  The
  * commands are as follows, and may be abbreviated down to one character
  * (with exception of 'scale' and 'stipple' down to "sc" and "st") and
  * may be upper or lower case.
diff --git a/src/preproc/html/pushback.cpp b/src/preproc/html/pushback.cpp
index eee746ba7..802c3b72a 100644
--- a/src/preproc/html/pushback.cpp
+++ b/src/preproc/html/pushback.cpp
@@ -301,7 +301,7 @@ double pushBackBuffer::readNumber (void)
 }
 
 /*
- *  readString - reads a string terminated by white space
+ *  readString - reads a string terminated by whitespace
  *               and returns a malloced area of memory containing
  *               a copy of the characters.
  */
diff --git a/src/preproc/refer/ref.cpp b/src/preproc/refer/ref.cpp
index 9e1b5e7a4..80c63d7bd 100644
--- a/src/preproc/refer/ref.cpp
+++ b/src/preproc/refer/ref.cpp
@@ -107,7 +107,7 @@ reference::reference(const char *start, int len, 
reference_id *ridp)
          const char *p = ptr;
          while (ptr < end && *ptr != '\n')
            ptr++;
-         // strip trailing white space
+         // strip trailing whitespace
          const char *q = ptr;
          while (q > p && q[-1] != '\n' && csspace(q[-1]))
            q--;
diff --git a/src/roff/troff/input.cpp b/src/roff/troff/input.cpp
index c808bc66c..c2d4238f9 100644
--- a/src/roff/troff/input.cpp
+++ b/src/roff/troff/input.cpp
@@ -6234,7 +6234,7 @@ static int ury_reg_contents = 0;
 #define DSC_LINE_MAX_ENFORCE    0
 #define DSC_LINE_MAX_CHECKED    1
 
-// Input characters to be considered as white space, when reading
+// Input characters to be considered as whitespace, when reading
 // PostScript file comments.
 //
 cset white_space("\n\r \t");
@@ -6415,7 +6415,7 @@ int psbb_locator::parse_bounding_box(const char *context)
     }
     else {
       // ...but if we can't parse four numbers, skip over any
-      // initial white space...
+      // initial whitespace...
       //
       while (*context == '\x20' || *context == '\t')
        context++;
diff --git a/tmac/groff_mdoc.7.man b/tmac/groff_mdoc.7.man
index e613b58cf..a12c44a8e 100644
--- a/tmac/groff_mdoc.7.man
+++ b/tmac/groff_mdoc.7.man
@@ -1418,7 +1418,7 @@ The result is:
 The punctuation is not recognized and all is output in the
 font used by
 .Ql .Ar .
-If the punctuation is separated by a leading white space:
+If the punctuation is separated by a leading whitespace:
 .
 .
 .Pp



reply via email to

[Prev in Thread] Current Thread [Next in Thread]
diff --git a/src/libs/libdriver/input.cpp b/src/libs/libdriver/input.cpp
index 821b526bd..6cff913f5 100644
--- a/src/libs/libdriver/input.cpp
+++ b/src/libs/libdriver/input.cpp
@@ -59,7 +59,7 @@
      3 lines having a fixed structure, while classical troff specified
      the sequence of the first 3 commands without further
      restrictions.  Now the parser is smart about additional
-     white space, comments, and empty lines in the prologue.
+     whitespace, comments, and empty lines in the prologue.
    - The old parser allowed space characters only as syntactical
      separators, while classical troff had tab characters as well.
      Now any sequence of tabs and/or spaces is a syntactical
@@ -395,7 +395,7 @@ IntArray *get_possibly_integer_args();
 char *get_string_arg(void);    // read in next string arg, ended by WS
 inline bool is_space_or_tab(const Char);
                                // test on space/tab char
-Char next_arg_begin(void);     // skip white space on current line
+Char next_arg_begin(void);     // skip whitespace on current line
 Char next_command(void);       // go to next command, evt. diff. line
 inline bool odd(const int);    // test if integer is odd
 void position_to_end_of_args(const IntArray * const);
@@ -900,7 +900,7 @@ get_string_arg(void)
     buf.append(c);
     c = get_char();
   }
-  unget_char(c);               // restore white space
+  unget_char(c);               // restore whitespace
   return buf.make_string();
 }
 